################################################################################################################################
#
# Description:	This constraint file applies to the dual QDR II+ SRAM interface to the FPGA.
#
# Rev History: 	08-28-2013:	Changed timing constraint to 450 MHz and corrected IOSTANDARDs for 1.8V HSTL.
#				05-12-2013:	Removed a placement constraint that produced a bitstream generation error in Vivado 2014.
#				09-04-2013:	Inital release.
#
################################################################################################################################

###################################################### Timing Constraints ######################################################

# Set the SRAM clock fixed frequency to 450 MHz.
create_clock -name qdriip_sys_clk -period 2.222 [get_ports qdriip_sys_clk_p]
set_clock_groups -name async_qdriip_sys_clk -asynchronous -group [get_clocks qdriip_sys_clk]

###################################################### Pinout Constraints ######################################################
# Note: The external component and pin name connected to each PACKAGE_PIN is shown as a comment (#component:pin).

# System clock assignment
set_property PACKAGE_PIN AA10 [get_ports {qdriip_sys_clk_p}];  #TP53A:CLKP

#SRAM-A pin assignments.
set_property PACKAGE_PIN AD20 [get_ports {sram_a_qdriip_k_p}];  #GS81302DT20:K
set_property PACKAGE_PIN AE20 [get_ports {sram_a_qdriip_k_n}];  #GS81302DT20:KN
set_property PACKAGE_PIN AB11 [get_ports {sram_a_qdriip_cq}];  #GS81302DT20:CQ
set_property PACKAGE_PIN W16 [get_ports {sram_a_qdriip_w_n}];  #GS81302DT20:WN
set_property PACKAGE_PIN V18 [get_ports {sram_a_qdriip_r_n}];  #GS81302DT20:RN
set_property PACKAGE_PIN AA14 [get_ports {sram_a_qdriip_dll_off_n}];  #GS81302DT20:DoffN
set_property PACKAGE_PIN AE13 [get_ports {sram_a_qdriip_qvld}];  #GS81302DT20:QVLD
set_property PACKAGE_PIN AC17 [get_ports {sram_a_qdriip_d[0]}];  #GS81302DT20:D[0]
set_property PACKAGE_PIN AD18 [get_ports {sram_a_qdriip_d[1]}];  #GS81302DT20:D[1]
set_property PACKAGE_PIN AC18 [get_ports {sram_a_qdriip_d[2]}];  #GS81302DT20:D[2]
set_property PACKAGE_PIN AD19 [get_ports {sram_a_qdriip_d[3]}];  #GS81302DT20:D[3]
set_property PACKAGE_PIN AC19 [get_ports {sram_a_qdriip_d[4]}];  #GS81302DT20:D[4]
set_property PACKAGE_PIN AB19 [get_ports {sram_a_qdriip_d[5]}];  #GS81302DT20:D[5]
set_property PACKAGE_PIN AA19 [get_ports {sram_a_qdriip_d[6]}];  #GS81302DT20:D[6]
set_property PACKAGE_PIN AB20 [get_ports {sram_a_qdriip_d[7]}];  #GS81302DT20:D[7]
set_property PACKAGE_PIN AA20 [get_ports {sram_a_qdriip_d[8]}];  #GS81302DT20:D[8]
set_property PACKAGE_PIN Y16 [get_ports {sram_a_qdriip_d[9]}];  #GS81302DT20:D[9]
set_property PACKAGE_PIN AB16 [get_ports {sram_a_qdriip_d[10]}];  #GS81302DT20:D[10]
set_property PACKAGE_PIN AB14 [get_ports {sram_a_qdriip_d[11]}];  #GS81302DT20:D[11]
set_property PACKAGE_PIN AC16 [get_ports {sram_a_qdriip_d[12]}];  #GS81302DT20:D[12]
set_property PACKAGE_PIN AC14 [get_ports {sram_a_qdriip_d[13]}];  #GS81302DT20:D[13]
set_property PACKAGE_PIN Y15 [get_ports {sram_a_qdriip_d[14]}];  #GS81302DT20:D[14]
set_property PACKAGE_PIN AA15 [get_ports {sram_a_qdriip_d[15]}];  #GS81302DT20:D[15]
set_property PACKAGE_PIN AB15 [get_ports {sram_a_qdriip_d[16]}];  #GS81302DT20:D[16]
set_property PACKAGE_PIN AD14 [get_ports {sram_a_qdriip_d[17]}];  #GS81302DT20:D[17]
set_property PACKAGE_PIN AC11 [get_ports {sram_a_qdriip_q[0]}];  #GS81302DT20:Q[0]
set_property PACKAGE_PIN AD13 [get_ports {sram_a_qdriip_q[1]}];  #GS81302DT20:Q[1]
set_property PACKAGE_PIN AC12 [get_ports {sram_a_qdriip_q[2]}];  #GS81302DT20:Q[2]
set_property PACKAGE_PIN AB12 [get_ports {sram_a_qdriip_q[3]}];  #GS81302DT20:Q[3]
set_property PACKAGE_PIN AC13 [get_ports {sram_a_qdriip_q[4]}];  #GS81302DT20:Q[4]
set_property PACKAGE_PIN AA12 [get_ports {sram_a_qdriip_q[5]}];  #GS81302DT20:Q[5]
set_property PACKAGE_PIN AA13 [get_ports {sram_a_qdriip_q[6]}];  #GS81302DT20:Q[6]
set_property PACKAGE_PIN Y12 [get_ports {sram_a_qdriip_q[7]}];  #GS81302DT20:Q[7]
set_property PACKAGE_PIN Y13 [get_ports {sram_a_qdriip_q[8]}];  #GS81302DT20:Q[8]
set_property PACKAGE_PIN AF13 [get_ports {sram_a_qdriip_q[9]}];  #GS81302DT20:Q[9]
set_property PACKAGE_PIN AE12 [get_ports {sram_a_qdriip_q[10]}];  #GS81302DT20:Q[10]
set_property PACKAGE_PIN AF12 [get_ports {sram_a_qdriip_q[11]}];  #GS81302DT20:Q[11]
set_property PACKAGE_PIN AD11 [get_ports {sram_a_qdriip_q[12]}];  #GS81302DT20:Q[12]
set_property PACKAGE_PIN AD10 [get_ports {sram_a_qdriip_q[13]}];  #GS81302DT20:Q[13]
set_property PACKAGE_PIN AE10 [get_ports {sram_a_qdriip_q[14]}];  #GS81302DT20:Q[14]
set_property PACKAGE_PIN AF9 [get_ports {sram_a_qdriip_q[15]}];  #GS81302DT20:Q[15]
set_property PACKAGE_PIN AF10 [get_ports {sram_a_qdriip_q[16]}];  #GS81302DT20:Q[16]
set_property PACKAGE_PIN AF8 [get_ports {sram_a_qdriip_q[17]}];  #GS81302DT20:Q[17]
set_property PACKAGE_PIN AF20 [get_ports {sram_a_qdriip_sa[20]}];  #GS81302DT20:SA[20]
set_property PACKAGE_PIN AE18 [get_ports {sram_a_qdriip_sa[19]}];  #GS81302DT20:SA[19]
set_property PACKAGE_PIN AF17 [get_ports {sram_a_qdriip_sa[18]}];  #GS81302DT20:SA[18]
set_property PACKAGE_PIN AD15 [get_ports {sram_a_qdriip_sa[17]}];  #GS81302DT20:SA[17]
set_property PACKAGE_PIN AF15 [get_ports {sram_a_qdriip_sa[16]}];  #GS81302DT20:SA[16]
set_property PACKAGE_PIN AF14 [get_ports {sram_a_qdriip_sa[15]}];  #GS81302DT20:SA[15]
set_property PACKAGE_PIN AF19 [get_ports {sram_a_qdriip_sa[14]}];  #GS81302DT20:SA[14]
set_property PACKAGE_PIN AE17 [get_ports {sram_a_qdriip_sa[13]}];  #GS81302DT20:SA[13]
set_property PACKAGE_PIN AE16 [get_ports {sram_a_qdriip_sa[12]}];  #GS81302DT20:SA[12]
set_property PACKAGE_PIN AE15 [get_ports {sram_a_qdriip_sa[11]}];  #GS81302DT20:SA[11]
set_property PACKAGE_PIN AF18 [get_ports {sram_a_qdriip_sa[10]}];  #GS81302DT20:SA[10]
set_property PACKAGE_PIN Y17 [get_ports {sram_a_qdriip_sa[9]}];  #GS81302DT20:SA[9]
set_property PACKAGE_PIN AD16 [get_ports {sram_a_qdriip_sa[8]}];  #GS81302DT20:SA[8]
set_property PACKAGE_PIN Y18 [get_ports {sram_a_qdriip_sa[7]}];  #GS81302DT20:SA[7]
set_property PACKAGE_PIN V16 [get_ports {sram_a_qdriip_sa[6]}];  #GS81302DT20:SA[6]
set_property PACKAGE_PIN W18 [get_ports {sram_a_qdriip_sa[5]}];  #GS81302DT20:SA[5]
set_property PACKAGE_PIN W15 [get_ports {sram_a_qdriip_sa[4]}];  #GS81302DT20:SA[4]
set_property PACKAGE_PIN V19 [get_ports {sram_a_qdriip_sa[3]}];  #GS81302DT20:SA[3]
set_property PACKAGE_PIN W19 [get_ports {sram_a_qdriip_sa[2]}];  #GS81302DT20:SA[2]
set_property PACKAGE_PIN V14 [get_ports {sram_a_qdriip_sa[1]}];  #GS81302DT20:SA[1]
set_property PACKAGE_PIN W14 [get_ports {sram_a_qdriip_sa[0]}];  #GS81302DT20:SA[0]
set_property PACKAGE_PIN AB17 [get_ports {sram_a_qdriip_bw_n[0]}];  #GS81302DT20:BWN[0]
set_property PACKAGE_PIN AA17 [get_ports {sram_a_qdriip_bw_n[1]}];  #GS81302DT20:BWN[0]

#SRAM-B pin assignments.
set_property PACKAGE_PIN AB1 [get_ports {sram_b_qdriip_k_p}];  #GS81302DT20:K
set_property PACKAGE_PIN AC1 [get_ports {sram_b_qdriip_k_n}];  #GS81302DT20:KN
set_property PACKAGE_PIN AC9 [get_ports {sram_b_qdriip_cq}];  #GS81302DT20:CQ
set_property PACKAGE_PIN V3 [get_ports {sram_b_qdriip_w_n}];  #GS81302DT20:WN
set_property PACKAGE_PIN U6 [get_ports {sram_b_qdriip_r_n}];  #GS81302DT20:RN
set_property PACKAGE_PIN Y5 [get_ports {sram_b_qdriip_dll_off_n}];  #GS81302DT20:DoffN       
set_property PACKAGE_PIN AA7 [get_ports {sram_b_qdriip_qvld}];  #GS81302DT20:QVLD
set_property PACKAGE_PIN AC4 [get_ports {sram_b_qdriip_d[0]}];  #GS81302DT20:D[0]
set_property PACKAGE_PIN AD5 [get_ports {sram_b_qdriip_d[1]}];  #GS81302DT20:D[1]
set_property PACKAGE_PIN AB5 [get_ports {sram_b_qdriip_d[2]}];  #GS81302DT20:D[2]
set_property PACKAGE_PIN AB4 [get_ports {sram_b_qdriip_d[3]}];  #GS81302DT20:D[3]
set_property PACKAGE_PIN AA5 [get_ports {sram_b_qdriip_d[4]}];  #GS81302DT20:D[4]
set_property PACKAGE_PIN AD6 [get_ports {sram_b_qdriip_d[5]}];  #GS81302DT20:D[5]
set_property PACKAGE_PIN AA4 [get_ports {sram_b_qdriip_d[6]}];  #GS81302DT20:D[6]
set_property PACKAGE_PIN AC6 [get_ports {sram_b_qdriip_d[7]}];  #GS81302DT20:D[7]
set_property PACKAGE_PIN AB6 [get_ports {sram_b_qdriip_d[8]}];  #GS81302DT20:D[8]
set_property PACKAGE_PIN W1 [get_ports {sram_b_qdriip_d[9]}];  #GS81302DT20:D[9]
set_property PACKAGE_PIN Y1 [get_ports {sram_b_qdriip_d[10]}];  #GS81302DT20:QVLD
set_property PACKAGE_PIN V1 [get_ports {sram_b_qdriip_d[11]}];  #GS81302DT20:D[0]
set_property PACKAGE_PIN Y2 [get_ports {sram_b_qdriip_d[12]}];  #GS81302DT20:D[1]
set_property PACKAGE_PIN V2 [get_ports {sram_b_qdriip_d[13]}];  #GS81302DT20:D[2]
set_property PACKAGE_PIN AB2 [get_ports {sram_b_qdriip_d[14]}];  #GS81302DT20:D[14]
set_property PACKAGE_PIN Y3 [get_ports {sram_b_qdriip_d[15]}];  #GS81302DT20:D[15]
set_property PACKAGE_PIN AA3 [get_ports {sram_b_qdriip_d[16]}];  #GS81302DT20:D[16]
set_property PACKAGE_PIN AC2 [get_ports {sram_b_qdriip_d[17]}];  #GS81302DT20:D[17]
set_property PACKAGE_PIN AF7 [get_ports {sram_b_qdriip_q[0]}];  #GS81302DT20:Q[0]
set_property PACKAGE_PIN AE7 [get_ports {sram_b_qdriip_q[1]}];  #GS81302DT20:Q[1]
set_property PACKAGE_PIN AD8 [get_ports {sram_b_qdriip_q[2]}];  #GS81302DT20:Q[2]
set_property PACKAGE_PIN AC8 [get_ports {sram_b_qdriip_q[3]}];  #GS81302DT20:Q[3]
set_property PACKAGE_PIN AC7 [get_ports {sram_b_qdriip_q[4]}];  #GS81302DT20:Q[4]
set_property PACKAGE_PIN AD9 [get_ports {sram_b_qdriip_q[5]}];  #GS81302DT20:Q[5]
set_property PACKAGE_PIN AB9 [get_ports {sram_b_qdriip_q[6]}];  #GS81302DT20:Q[6]
set_property PACKAGE_PIN AB7 [get_ports {sram_b_qdriip_q[7]}];  #GS81302DT20:Q[7]
set_property PACKAGE_PIN AA9 [get_ports {sram_b_qdriip_q[8]}];  #GS81302DT20:Q[8]
set_property PACKAGE_PIN V7 [get_ports {sram_b_qdriip_q[9]}];  #GS81302DT20:Q[9]
set_property PACKAGE_PIN V8 [get_ports {sram_b_qdriip_q[10]}];  #GS81302DT20:Q[10]
set_property PACKAGE_PIN V9 [get_ports {sram_b_qdriip_q[11]}];  #GS81302DT20:Q[11]
set_property PACKAGE_PIN Y7 [get_ports {sram_b_qdriip_q[12]}];  #GS81302DT20:Q[12]
set_property PACKAGE_PIN Y8 [get_ports {sram_b_qdriip_q[13]}];  #GS81302DT20:Q[13]
set_property PACKAGE_PIN W10 [get_ports {sram_b_qdriip_q[14]}];  #GS81302DT20:Q[14]
set_property PACKAGE_PIN W9 [get_ports {sram_b_qdriip_q[15]}];  #GS81302DT20:Q[15]
set_property PACKAGE_PIN Y10 [get_ports {sram_b_qdriip_q[16]}];  #GS81302DT20:Q[16]
set_property PACKAGE_PIN Y11 [get_ports {sram_b_qdriip_q[17]}];  #GS81302DT20:Q[17]
set_property PACKAGE_PIN AE6 [get_ports {sram_b_qdriip_sa[20]}];  #GS81302DT20:SA[20]
set_property PACKAGE_PIN AF5 [get_ports {sram_b_qdriip_sa[19]}];  #GS81302DT20:SA[19]
set_property PACKAGE_PIN AF4 [get_ports {sram_b_qdriip_sa[18]}];  #GS81302DT20:SA[18]
set_property PACKAGE_PIN AF3 [get_ports {sram_b_qdriip_sa[17]}];  #GS81302DT20:SA[17]
set_property PACKAGE_PIN AE2 [get_ports {sram_b_qdriip_sa[16]}];  #GS81302DT20:SA[16]
set_property PACKAGE_PIN AD1 [get_ports {sram_b_qdriip_sa[15]}];  #GS81302DT20:SA[15]
set_property PACKAGE_PIN AE5 [get_ports {sram_b_qdriip_sa[14]}];  #GS81302DT20:SA[14]
set_property PACKAGE_PIN AD4 [get_ports {sram_b_qdriip_sa[13]}];  #GS81302DT20:SA[13]
set_property PACKAGE_PIN AE3 [get_ports {sram_b_qdriip_sa[12]}];  #GS81302DT20:SA[12]
set_property PACKAGE_PIN AE1 [get_ports {sram_b_qdriip_sa[11]}];  #GS81302DT20:SA[11]
set_property PACKAGE_PIN AD3 [get_ports {sram_b_qdriip_sa[10]}];  #GS81302DT20:SA[10]
set_property PACKAGE_PIN W4 [get_ports {sram_b_qdriip_sa[9]}];  #GS81302DT20:SA[9]
set_property PACKAGE_PIN AF2 [get_ports {sram_b_qdriip_sa[8]}];  #GS81302DT20:SA[8]
set_property PACKAGE_PIN W5 [get_ports {sram_b_qdriip_sa[7]}];  #GS81302DT20:SA[7]
set_property PACKAGE_PIN V4 [get_ports {sram_b_qdriip_sa[6]}];  #GS81302DT20:SA[6]
set_property PACKAGE_PIN V6 [get_ports {sram_b_qdriip_sa[5]}];  #GS81302DT20:SA[5]
set_property PACKAGE_PIN W3 [get_ports {sram_b_qdriip_sa[4]}];  #GS81302DT20:SA[4]
set_property PACKAGE_PIN U7 [get_ports {sram_b_qdriip_sa[3]}];  #GS81302DT20:SA[3]
set_property PACKAGE_PIN W6 [get_ports {sram_b_qdriip_sa[2]}];  #GS81302DT20:SA[2]
set_property PACKAGE_PIN U2 [get_ports {sram_b_qdriip_sa[1]}];  #GS81302DT20:SA[1]
set_property PACKAGE_PIN U1 [get_ports {sram_b_qdriip_sa[0]}];  #GS81302DT20:SA[0]
set_property PACKAGE_PIN AC3 [get_ports {sram_b_qdriip_bw_n[0]}];  #GS81302DT20:BWN[0]
set_property PACKAGE_PIN AA2 [get_ports {sram_b_qdriip_bw_n[1]}];  #GS81302DT20:BWN[0]
